# Contxt Python SDK

_the Python SDK for Contxt_

[![CI](https://github.com/ndustrialio/contxt-sdk-python/workflows/CI/badge.svg)](https://github.com/ndustrialio/contxt-sdk-python/actions?query=workflow%3ACI)
[![pypi version](https://img.shields.io/pypi/v/contxt-sdk.svg)](https://pypi.org/project/contxt-sdk/)
![python](https://img.shields.io/badge/python-3.9+-blue.svg)

## Installation

```sh
pip install contxt-sdk
```

## CLI Usage

```sh
contxt --help
```

## Tests

```sh
docker compose up -d --wait
poetry run poe test
docker compose down
```

## Documentation

Please refer to <https://ndustrialio.github.io/contxt-sdk-python>.

## Contributing

Please refer to [CONTRIBUTING.md](CONTRIBUTING.md).

